@media all {
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    .character-cards {
        flex: 0 0 50%;
        width: 100%;
        margin-right: auto;
        margin-left: auto;
        max-width: 180rem;
    }

    .cards_container {
        display: flex;
        flex-wrap: wrap;
        list-style: none;
        margin: 0 -1rem 2rem -1rem;
        padding: 0;
        justify-content: center;
    }

    .cards_container .card {
        position: relative;
        display: -ms-flexbox;
        display: flex;
        -ms-flex-direction: column;
        flex-direction: column;
        min-width: 0;
        word-wrap: break-word;
        background-clip: border-box;
        border: 1px solid rgba(0, 0, 0, .125);
        border-radius: 0.25rem;
    }

    .template-dark-mode .cards_container .card {
        background-color: rgb(100, 100, 100);
    }

    .cards_container .card-header,
    .cards_container .card-footer {
        padding: 0.75rem 1.25rem;
        margin-bottom: 0;
        background-color: rgba(0, 0, 0, 0.03);
        border-bottom: 1px solid rgba(0, 0, 0, 0.125);
        text-align: center;
    }

    .cards_container .card-footer {
        border-bottom: none;
        border-top: 1px solid rgba(0, 0, 0, 0.125);
    }

    .cards_container .card-header:first-child {
        border-radius: calc(0.25rem - 1px) calc(0.25rem - 1px) 0 0;
    }

    .cards_container .card-body {
        -ms-flex: 1 1 auto;
        flex: 1 1 auto;
        min-height: 1px;
        padding: 1.25rem;
    }

    .cards_container .cards_item {
        display: flex;
        padding: 1rem;
    }

    .cards_container .cards_item .card {
        display: flex;
        flex-direction: column;
    }

    .cards_container img {
        max-width: 100%;
    }

    .cards_container .text-center {
        text-align: center;
    }

    .cards_container .label {
        display: inline;
        padding: 0.3rem 0.6rem 0.3rem;
        font-size: 75%;
        font-weight: 700;
        line-height: 1;
        color: rgb(255,255,255);
        text-align: center;
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: 0.1rem;
        cursor: pointer;
    }

    .cards_container .label-requested-scope {
        margin-left: 1rem;
        background-color: rgb(192, 192, 192);
        color: rgb(54, 54, 54);
    }

    .cards_container .select-character {
        width: 100%;
        padding: 0.35rem;
        cursor: pointer;
    }

    .cards_container form {
        margin-bottom: 0.3rem;
    }

    .cards_container .btn-new-character-sso {
        padding: 0;
        border: none;
        cursor: pointer;
    }

    /* corp and alliance logo
    ------------------------------------------------------------------------------------------------------------------*/
    .aa-memberaudit-launcher-character-image {
        display: block;
        position: relative;
        top: 0;
        bottom: 0;
        left: 0;
        right: 0;
    }

    .aa-memberaudit-alliance-logo {
        position: absolute;
        left: 0.5rem;
        bottom: 0.5rem;
        width: 48px;
        height: 48px;
        z-index: 2;
    }

    .aa-memberaudit-corporation-logo {
        position: absolute;
        bottom: 0.5rem;
        right: 0.5rem;
        width: 48px;
        height: 48px;
        z-index: 2;
    }

    .aa-memberaudit-alliance-logo img,
    .aa-memberaudit-corporation-logo img {
        opacity: 0.3;
        transition: opacity 0.5s ease-in-out;
        -moz-transition: opacity 0.5s ease-in-out;
        -webkit-transition: opacity 0.5s ease-in-out;
    }

    .character-cards .card:hover .aa-memberaudit-alliance-logo img,
    .character-cards .card:hover .aa-memberaudit-corporation-logo img {
        opacity: 1;
    }
}

@media (min-width: 40rem) {
    .cards_container .cards_item {
        width: calc(100% / 2);
    }
}

@media (min-width: 56rem) {
    .cards_container .cards_item {
        width: calc(100% / 3);
    }
}

@media (min-width: 75rem) {
    .cards_container .cards_item {
        width: calc(100% / 4);
    }
}

@media (min-width: 90rem) {
    .cards_container .cards_item {
        width: calc(100% / 5);
    }
}


@media (min-width: 105rem) {
    .cards_container .cards_item {
        width: calc(100% / 6);
    }
}
