{% extends 'allianceauth/base.html' %}
{% load i18n %}
{% load navactive %}

{% block page_title %}{% translate "miningtaxes" %}{% endblock %}

{% block content %}
    <div class="miningtaxes">
	 <br/>

	<nav class="navbar navbar-default">
    <div class="container-fluid">
        <div class="navbar-header">
            <button type="button" class="navbar-toggle collapsed" data-toggle="collapse"
                data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                <span class="sr-only">{% translate "Toggle navigation" %}</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>

            <a class="navbar-brand" href="{% url 'miningtaxes:index' %}">Mining Taxes</a>
	</div>
        <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
            <ul class="nav navbar-nav">
	        <li class="{% navactive request 'miningtaxes:ore_prices' %}">
                    <a href="{% url 'miningtaxes:ore_prices' %}">
                        {% translate 'Current Ore Prices' %}
                    </a>
                </li>
	        <li class="{% navactive request 'miningtaxes:faq' %}">
                    <a href="{% url 'miningtaxes:faq' %}">
                        {% translate 'FAQ' %}
                    </a>
                </li>
	        <li class="{% navactive request 'miningtaxes:launcher' %}">
                    <a href="{% url 'miningtaxes:launcher' %}">
                        {% translate 'Setup' %}
                    </a>
                </li>

		{% if perms.miningtaxes.auditor_access %}
		<li class="{% navactive request 'miningtaxes:admin_tables' %}">
                        <a href="{% url 'miningtaxes:admin_tables' %}">
                            {% translate 'Audit Tables' %}
                        </a>
                </li>
                {% endif %}
		{% if perms.miningtaxes.admin_access %}
		<li class="{% navactive request 'miningtaxes:admin_launcher' %}">
                        <a href="{% url 'miningtaxes:admin_launcher' %}">
                            {% translate 'Admin Setup' %}
                        </a>
                </li>
                {% endif %}

	    </ul>
        </div>
        </div>
	</nav>
        {% block details %}{% endblock %}
    </div>
{% endblock %}
