# Generated by Django 4.0.7 on 2022-11-08 03:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("miningtaxes", "0002_all_models"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access this app"),
                    (
                        "admin_access",
                        "Can set tax rates for groups and add accountant characters",
                    ),
                    ("auditor_access", "Can view all registered characters data"),
                ),
            },
        ),
    ]
